%global major_version %%(echo %{version} | cut -d. -f1)
%global minor_version %%(echo %{version} | cut -d. -f2)

Summary:        Protocol definitions and daemon for D-Bus at-spi
Name:           at-spi2-core
Version:        2.49.90
Release:        2%{?dist}
License:        LGPLv2+
URL:            https://gitlab.gnome.org/GNOME/at-spi2-core
Source0:        http://download.gnome.org/sources/at-spi2-core/%{major_version}.%{minor_version}/%{name}-%{version}.tar.xz
# https://bugzilla.redhat.com/show_bug.cgi?id=1821345
Source1:        xwayland-session-scriptlet

BuildRequires:  gettext
BuildRequires:  gobject-introspection-devel
BuildRequires:  meson
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xtst)

Requires:       dbus

%description
contains the DBus interface definitions for AT-SPI, the Assistive Technology 
Service Provider Interface — the core of an accessibility stack for free 
software systems.  It also contains the basic daemons of the accessibility 
stack.

%package devel
Summary: Development files and headers for at-spi2-core
Requires: %{name} = %{version}-%{release}

%description devel
The at-spi2-core-devel package includes the header files and API documentation 
for libatspi.

%package -n atk
Summary: Interfaces for accessibility support
Requires: at-spi2-core = %{version}-%{release}

%description -n atk
The ATK library provides a set of interfaces for adding accessibility
support to applications and graphical user interface toolkits. By
supporting the ATK interfaces, an application or toolkit can be used
with tools such as screen readers, magnifiers, and alternative input
devices.

%package -n atk-devel
Summary: Development files for the ATK accessibility toolkit

%description -n atk-devel
This package includes libraries, header files, and developer documentation
needed for development of applications or toolkits which use ATK.

%package -n at-spi2-atk
Summary:  A GTK+ module that bridges ATK to D-Bus at-spi
Requires: atk = %{version}-%{release}
Requires: at-spi2-core = %{version}-%{release}

%description -n at-spi2-atk
at-spi allows assistive technologies to access GTK-based
applications. Essentially it exposes the internals of applications for
automation, so tools such as screen readers, magnifiers, or even
scripting interfaces can query and interact with GUI controls.

This version of at-spi is a major break from previous versions.
It has been completely rewritten to use D-Bus rather than
ORBIT / CORBA for its transport protocol.

This package includes a gtk-module that bridges ATK to the new
D-Bus based at-spi.

%package -n at-spi2-atk-devel
Summary:  A GTK+ module that bridges ATK to D-Bus at-spi
Requires: at-spi2-atk = %{version}-%{release}

%description -n at-spi2-atk-devel
The at-spi2-atk-devel package includes the header files for the at-spi2-atk
library.


%prep
%autosetup -p1



%build
%meson -Ddocs=false -Ddefault_bus=dbus-broker -Ddbus_daemon=/usr/bin/dbus-daemon -Ddbus_broker=/usr/bin/dbus-broker-launch
%meson_build



%install
%meson_install
install -d %{buildroot}%{_sysconfdir}/xdg/Xwayland-session.d
install -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/xdg/Xwayland-session.d/00-at-spi

%{find_lang} %{name}



%files -f %{name}.lang
%license COPYING
%doc NEWS README.md
%{_libexecdir}/at-spi2-registryd
%{_libdir}/libatspi.so.*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Atspi-2.0.typelib
%{_libexecdir}/at-spi-bus-launcher
%dir %{_datadir}/defaults
%dir %{_datadir}/defaults/at-spi2
%{_datadir}/defaults/at-spi2/accessibility.conf
%{_sysconfdir}/xdg/autostart/at-spi-dbus-bus.desktop
%dir %{_sysconfdir}/xdg/Xwayland-session.d
%{_sysconfdir}/xdg/Xwayland-session.d/00-at-spi
%{_datadir}/dbus-1/accessibility-services/org.a11y.atspi.Registry.service
%{_datadir}/dbus-1/services/org.a11y.Bus.service
%{_userunitdir}/at-spi-dbus-bus.service

%files devel
%{_libdir}/libatspi.so
%{_libdir}/pkgconfig/atspi-2.pc
%{_includedir}/at-spi-2.0
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Atspi-2.0.gir

%files -n atk
%license COPYING
%{_libdir}/libatk-1.0.so.*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Atk-1.0.typelib

%files -n atk-devel
%{_libdir}/libatk-1.0.so
%{_includedir}/atk-1.0
%{_libdir}/pkgconfig/atk.pc
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Atk-1.0.gir

%files -n at-spi2-atk
%license COPYING
%dir %{_libdir}/gtk-2.0
%dir %{_libdir}/gtk-2.0/modules
%{_libdir}/gtk-2.0/modules/libatk-bridge.so
%{_libdir}/gnome-settings-daemon-3.0/gtk-modules/at-spi2-atk.desktop
%{_libdir}/libatk-bridge-2.0.so.*

%files -n at-spi2-atk-devel
%{_includedir}/at-spi2-atk/2.0/atk-bridge.h
%{_libdir}/libatk-bridge-2.0.so
%{_libdir}/pkgconfig/atk-bridge-2.0.pc

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.49.90-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 22 2023 Miaojun Dong <zoedong@tencent.com> - 2.49.90-1
- Bump version to 2.49.90

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.44.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.44.1-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Sep 16 2022 Zhao Zhen <jeremiazhao@tencent.com> - 2.44.1-1
- Initial building
